/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.view.report.SaveReportDialog");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dojox.data.dom");
dojo.require("com.ibm.rational.report.web.core.app.internal.common.CommonDialog");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.view.report", "Messages");
dojo.require("com.ibm.rational.report.web.core.app.internal.Util");

var CommonMessages	    	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
var ServiceabilityMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
var ReportMessages			= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.view.report", "Messages");
var Util					= com.ibm.rational.report.web.core.app.internal.Util;

/**
 * Displays the New Report Query view.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.view.report.SaveReportDialog",
	[dijit._Widget, dijit._Templated], {
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/view/report/templates/SaveReportDialog.html"),
	
	constructor: function(args) {
		this._controller = args.controller;
		this._title = args.title;
	},
	
	postCreate: function() {
		this._initText();
		
		var self = this;	
				
		this._fillParentNodeControl();
		
		this.saveButton.disabled = true;
		
		dojo.connect(this.nameText, "onkeyup",
			function(e) {
				dojo.stopEvent(e);
				var name = dojo.trim(self.nameText.value);
				self.saveButton.disabled = (name.length == 0);
			}
		);			
		
		dojo.connect(this.nameText, "onkeypress",
			function(e) {
				if(e.charCode == 47 || e.charCode == 92 || e.charCode == 42 || e.charCode == 63 ||
				   e.charCode == 124 || e.charCode == 62 || e.charCode == 60 || e.charCode == 58  || e.charCode == 34){
						e.preventDefault();
				}
			}
		);
		
		this.dialog = new com.ibm.rational.report.web.core.app.internal.common.CommonDialog({
			contentNode: this.contentNode,
			primaryTitle: this._title,
			width: "640px",
			isClosable: true
		});
		this.closeButton.focus();
	},
	
	_initText: function() {
		dojox.data.dom.removeChildren(this.saveAsLabel);
		this.saveAsLabel.appendChild(document.createTextNode(ReportMessages.SAVE_REPORT_VIEWER_SAVE_AS_LABEL));

		dojox.data.dom.removeChildren(this.typeCombo);		
		this.typeCombo.options.add(new Option(CommonMessages.REPORT_QUERY, "REPORT_QUERY")); 
		this.typeCombo.options.add(new Option(CommonMessages.REPORT_SNAPSHOT, "REPORT_SNAPSHOT"));
		
		dojox.data.dom.removeChildren(this.nameLabel);
		this.nameLabel.appendChild(document.createTextNode(ReportMessages.SAVE_REPORT_VIEWER_NAME_LABEL));
		
		dojox.data.dom.removeChildren(this.descriptionLabel);
		this.descriptionLabel.appendChild(document.createTextNode(ReportMessages.SAVE_REPORT_VIEWER_DESCRIPTION_LABEL));
			
		dojox.data.dom.removeChildren(this.parentFolderLabel);
		this.parentFolderLabel.appendChild(document.createTextNode(ReportMessages.SAVE_REPORT_VIEWER_PARENT_FOLDER_LABEL));
	
		dojox.data.dom.removeChildren(this.sharedLabel);
		this.sharedLabel.appendChild(document.createTextNode(ReportMessages.SAVE_REPORT_VIEWER_SHARED_LABEL));
		
		dojox.data.dom.removeChildren(this.saveButton);
		this.saveButton.appendChild(document.createTextNode(CommonMessages.SAVE_BUTTON_LABEL));
		
		dojox.data.dom.removeChildren(this.closeButton);
		this.closeButton.appendChild(document.createTextNode(CommonMessages.CLOSE_BUTTON_LABEL));
	},	
	
	_fillParentNodeControl:  function() {
		var nodes = this._controller.reportTreeParser.getValidParents(this._selectedNodeId);		
		if (nodes != null && nodes.length > 0) {
			for (var i = 0; i < nodes.length; i++) {
				var node = nodes[i];
				if (node.report) continue;
				
				var name = node.name;
				var nodeId = node.itemId;
				
				if (nodeId == "" || nodeId == null) {
					continue;
				}
				
				var opt = new Option(name, nodeId, false, false);
				opt.setAttribute("shared", node.shared);
				this.parentFolder.options[this.parentFolder.options.length] = opt;
			}
		}
	},
	
	close: function() {
		this.dialog.close();
	}

});

})();